@@ -75,6 +75,7 @@ class MqttBinarysensor(MqttEntity):
             "payload_off": "OFF",
             "payload_on": "ON",
             "qos": 0,
+            "state_topic": self.state_topic,
             "unique_id": self.unique_id,
         }
         if self._device_class:
@@ -85,8 +86,6 @@ class MqttBinarysensor(MqttEntity):
             config_payload["icon"] = self._icon
         if self._object_id:
             config_payload["object_id"] = self._object_id
-        if self._device_class:
-            config_payload["state_topic"] = self.state_topic
 
         self.logger.debug("%s: %s", self.config_topic, json.dumps(config_payload))
         self._mqtt_client.publish(
