@@ -54,12 +54,12 @@ class MqttEntity:
     @property
     def mqtt_discovery_root_topic(self):
         """Get MQTT root topic of the entity."""
-        return self._mqtt_discovery_root_topic
+        return self._mqtt_discovery_root_topic.lower()
 
     @property
     def mqtt_data_root_topic(self):
         """Get MQTT root topic of data of the entity."""
-        return self._mqtt_data_root_topic
+        return self._mqtt_data_root_topic.lower()
 
     @property
     def logger(self):
@@ -91,28 +91,28 @@ class MqttEntity:
         """MQTT Command topic to receive commands from Home Assistant."""
         return "/".join(
             (self._mqtt_data_root_topic, self._component, self.name, "command")
-        )
+        ).lower()
 
     @property
     def state_topic(self):
         """MQTT State topic to send state to Home Assistant."""
         return "/".join(
             (self._mqtt_data_root_topic, self._component, self.name, "state")
-        )
+        ).lower()
 
     @property
     def availability_topic(self):
         """MQTT availability topic to send entity availability to Home Assistant."""
         return "/".join(
             (self._mqtt_data_root_topic, self._component, self.name, "availability")
-        )
+        ).lower()
 
     @property
     def json_attributes_topic(self):
         """MQTT attributes topic to send attribute dict to Home Assistant."""
         return "/".join(
             (self._mqtt_data_root_topic, self._component, self.name, "attributes")
-        )
+        ).lower()
 
     @property
     def config_topic(self):
@@ -124,7 +124,7 @@ class MqttEntity:
                 self.unique_id.lower().replace(" ", "_"),
                 "config",
             )
-        )
+        ).lower()
 
     def send_available(self):
         """Set the availability to ON."""
